@@ -110,7 +110,14 @@ def django_db_setup(
 
     def teardown_database():
         with django_db_blocker.unblock():
-            teardown_databases(db_cfg, verbosity=request.config.option.verbose)
+            try:
+                teardown_databases(db_cfg, verbosity=request.config.option.verbose)
+            except Exception as exc:
+                request.node.warn(
+                    pytest.PytestWarning(
+                        "Error when trying to teardown test databases: %r" % exc
+                    )
+                )
 
     if not django_db_keepdb:
         request.addfinalizer(teardown_database)
@@ -122,7 +129,7 @@ def _django_db_fixture_helper(
     if is_django_unittest(request):
         return
 
-    if not transactional and "live_server" in request.funcargnames:
+    if not transactional and "live_server" in request.fixturenames:
         # Do nothing, we get called with transactional=True, too.
         return
 
@@ -148,10 +155,19 @@ def _django_db_fixture_helper(
 
 def _disable_native_migrations():
     from django.conf import settings
+    from django.core.management.commands import migrate
+
     from .migrations import DisableMigrations
 
     settings.MIGRATION_MODULES = DisableMigrations()
 
+    class MigrateSilentCommand(migrate.Command):
+        def handle(self, *args, **kwargs):
+            kwargs["verbosity"] = 0
+            return super(MigrateSilentCommand, self).handle(*args, **kwargs)
+
+    migrate.Command = MigrateSilentCommand
+
 
 # ############### User visible fixtures ################
 
@@ -171,11 +187,11 @@ def db(request, django_db_setup, django_db_blocker):
     over each other in the following order (the last one wins): ``db``,
     ``transactional_db``, ``django_db_reset_sequences``.
     """
-    if "django_db_reset_sequences" in request.funcargnames:
+    if "django_db_reset_sequences" in request.fixturenames:
         request.getfixturevalue("django_db_reset_sequences")
     if (
-        "transactional_db" in request.funcargnames
-        or "live_server" in request.funcargnames
+        "transactional_db" in request.fixturenames
+        or "live_server" in request.fixturenames
     ):
         request.getfixturevalue("transactional_db")
     else:
@@ -196,7 +212,7 @@ def transactional_db(request, django_db_setup, django_db_blocker):
     over each other in the following order (the last one wins): ``db``,
     ``transactional_db``, ``django_db_reset_sequences``.
     """
-    if "django_db_reset_sequences" in request.funcargnames:
+    if "django_db_reset_sequences" in request.fixturenames:
         request.getfixturevalue("django_db_reset_sequences")
     _django_db_fixture_helper(request, django_db_blocker, transactional=True)
 
@@ -394,7 +410,7 @@ def _live_server_helper(request):
 
     It will also override settings only for the duration of the test.
     """
-    if "live_server" not in request.funcargnames:
+    if "live_server" not in request.fixturenames:
         return
 
     request.getfixturevalue("transactional_db")
